==> flamel_2008_04_28.zip: flamel/contents/WEB-INF/src/jp/arcanum/click/plugin/CounterControl.java <==
package jp.arcanum.click.plugin;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import jp.arcanum.click.ArUtil;
import jp.arcanum.click.PluginInterface;
import net.sf.click.Page;

public class CounterControl implements PluginInterface{

	
	/**
	 * JE^[
	 */
	private String counter = "";

	
	
	public void onDestroy(Map params, Page page) {
		
	}

	public void onGet(Map params, Page page) {
		
	}

	public void onInit(Map params, Page page) {
		page.addModel("counter", this);
	}

	public void onPost(Map params, Page page) {
	}

	public void onRender(Map params, Page page) {
		addCounter(page);
	}

	public boolean onSecurityCheck(Map params, Page page) {
		return true;
	}
	
	
	public String toString(){
		return counter;
	}
	
	
	
	private void addCounter(Page page){
		
    	
        //@JE^[t@Ceǂݍ
    	String filepath = page.getContext().getServletContext().getRealPath(ArUtil.PATH_COUNTER);
    	File file = new File(filepath);
    	if(!file.exists()){
    		return;
    	}
    	List list = ArUtil.readFile(filepath);
		String wk = (String)list.get(0);

		//gbvfBNg̏ꍇŌ{^ł͂Ȃꍇ̂݃JE^[Abv
        //String urltop = ArUtil.getProperty(this, ArUtil.PROP_SITE, "document_root");
        //if(urltop.equals("/")){
        //	urltop="";	//  AvP[Vgbv̏ꍇ//index.htmɂȂ邽ߍ폜
        //}
		
		// TODO ̃pX̏́AvOCꂽƂAƖvƂȂ̂
		//@̂܂܂ɂBcmsƂĔėpłȂB
        //if( ("/pages/index.htm").equals(page.getPath()) && ! this.kensaku.isClicked()){
        if( ("/pages/index.htm").equals(page.getPath()) ){
			
			//@ZbVɃJE^AbvtOꍇ̓XfɃAbvĂ
			if(page.getContext().getSession().getAttribute(COUNTER_FLG)==null){
				wk = Integer.toString(Integer.parseInt(wk) + 1);
				List wklist = new ArrayList();
				wklist.add(wk);
		    	ArUtil.writeFile(filepath, wklist);
			}
			
		}
        
        wk = "00000" + wk;
        this.counter = wk.substring(wk.length()-5,wk.length()) ;

		page.getContext().getSession().setAttribute(COUNTER_FLG, COUNTER_FLG);
		
	}

	/**
	 * JE^AbvtOBRZbVɂƃJE^[
	 * ɃAbvꂽɂȂ炵B
	 */
	public static final String COUNTER_FLG = "COUNTER_FLG";

}

==> flamel_2008_05_05.zip: flamel/contents/WEB-INF/src/jp/arcanum/click/plugin/CounterControl.java <==
package jp.arcanum.click.plugin;

import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;

import au.id.jericho.lib.html.Source;

import jp.arcanum.click.ArUtil;
import jp.arcanum.click.PluginInterface;
import net.sf.click.Page;

public class CounterControl implements PluginInterface{

	
	/**
	 * JE^[
	 */
	private String counter = "";

	
	
	public void onDestroy(Map params, Page page) {
		
	}

	public void onGet(Map params, Page page) {
		
	}

	public void onInit(Map params, Page page) {
		page.addModel("counter", this);
	}

	public void onPost(Map params, Page page) {
	}

	public void onRender(Map params, Page page) {
		addCounter(page);
	}

	public boolean onSecurityCheck(Map params, Page page) {
		return true;
	}
	
	
	public String toString(){
		return counter;
	}
	
	
	
	
	private void addCounter(Page page){
		
    	
        //@JE^[t@Ceǂݍ
    	String filepath = page.getContext().getServletContext().getRealPath(ArUtil.PATH_COUNTER);
    	File file = new File(filepath);
    	if(!file.exists()){
    		return;
    	}
    	List list = ArUtil.readFile(filepath);
    	String wk = (String)list.get(0);

		//gbvfBNg̏ꍇŌ{^ł͂Ȃꍇ̂݃JE^[Abv
        //String urltop = ArUtil.getProperty(this, ArUtil.PROP_SITE, "document_root");
        //if(urltop.equals("/")){
        //	urltop="";	//  AvP[Vgbv̏ꍇ//index.htmɂȂ邽ߍ폜
        //}
		
		// TODO ̃pX̏́AvOCꂽƂAƖvƂȂ̂
		//@̂܂܂ɂBcmsƂĔėpłȂB
        //if( ("/pages/index.htm").equals(page.getPath()) && ! this.kensaku.isClicked()){
        if( ("/pages/index.htm").equals(page.getPath()) ){
			
			//@ZbVɃJE^AbvtOꍇ̓XfɃAbvĂ
			if(page.getContext().getSession().getAttribute(COUNTER_FLG)==null){
				wk = Integer.toString(Integer.parseInt(wk) + 1);
				List wklist = new ArrayList();
				wklist.add(wk);
		    	ArUtil.writeFile(filepath, wklist);
			}
			
		}
        
        wk = "00000" + wk;
        this.counter = wk.substring(wk.length()-5,wk.length()) ;

		page.getContext().getSession().setAttribute(COUNTER_FLG, COUNTER_FLG);
		
	}

	/**
	 * JE^AbvtOBRZbVɂƃJE^[
	 * ɃAbvꂽɂȂ炵B
	 */
	public static final String COUNTER_FLG = "COUNTER_FLG";

}
